@@ -12,7 +12,7 @@ from fsspec import AbstractFileSystem
 from fsspec.utils import stringify_path
 from pydantic import Field
 
-from apppy.env import EnvSettings
+from apppy.env import Env, EnvSettings
 from apppy.fs.errors import (
     FileSystemNotFoundError,
     FileSystemPermissionsError,
@@ -435,8 +435,13 @@ class ProxyFileSystem(ABC):
 
 
 class FileSystemSettings(EnvSettings):
-    file_max_size_mb: int = Field(alias="APP_FS_FILE_MAX_SIZE_MB", default=32)
-    default_protocol: str = Field(alias="APP_FS_DEFAULT_PROTOCOL", default="local")
+    # FS_FILE_MAX_SIZE_MB
+    file_max_size_mb: int = Field(default=32)
+    # FS_DEFAULT_PROTOCOL
+    default_protocol: str = Field(default="local")
+
+    def __init__(self, env: Env) -> None:
+        super().__init__(env=env, domain_prefix="FS")
 
 
 class FileSystem(WithLogger):
